Installation
############

Installing HEROS is as simple as doing

.. code:: console

    git clone https://gitlab.com/atomiq-project/heros.git
    cd heros
    pip env
    pip install -r requirements.txt
    pip install .

It will automatically install the few requirements that HEROS has (mainly eclipse-zenoh) and you are ready to ready to create your first own HERO.